Directory

Catalog

338,192 skills · 109,547 with SKILL.md · 9,908 ranked on the leaderboard

All skills

#
Skill
Source
8W Activity
Installs
1
alicloud-media-ice-test Smoke test for alicloud-media-ice. Validate minimal authentication, API reachability, and one read-only query path.
cinience/alicloud-skills
156
2
alicloud-ai-cloud-call-center-test Smoke test for alicloud-ai-cloud-call-center. Validate minimal authentication, API reachability, and one read-only qu…
cinience/alicloud-skills
156
3
alicloud-security-id-verification-cloudauth-test Smoke test for alicloud-security-id-verification-cloudauth. Validate minimal authentication, API reachability, and on…
cinience/alicloud-skills
156
4
alicloud-platform-multicloud-docs-api-benchmark-test Smoke test for alicloud-platform-multicloud-docs-api-benchmark. Validate minimal authentication, API reachability, an…
cinience/alicloud-skills
156
5
alicloud-compute-swas-open-test Smoke test for alicloud-compute-swas-open. Validate minimal authentication, API reachability, and one read-only query…
cinience/alicloud-skills
156
6
alicloud-compute-fc-serverless-devs-test Smoke test for alicloud-compute-fc-serverless-devs. Validate minimal authentication, API reachability, and one read-o…
cinience/alicloud-skills
156
7
Research Multi-agent web research with mandatory URL verification, confidence-tagged output, and four depth modes (quick to de…
danielmiessler/lifeos
156
8
opportunity-scanner 4-stage funnel that screens all 500+ Hyperliquid perps down to the top trading opportunities. Scores setups 0-400 acr…
senpi-ai/senpi-skills
156
9
posthog-onboarding Help existing PostHog customers improve their PostHog instance. Triggers on "help [customer] improve their PostHog se…
posthog/skills
156
10
evidence-based-reviews Produce honest product reviews and buying guides without fabricated first-hand experience, using disclosed evidence t…
rampstackco/claude-skills
156
11
researching-ai-news Research and compile the latest AI news from across the industry. Use this skill when asked to find AI news, get AI u…
jamesgray007/hoai-course
156
12
git-commit Execute git commit with conventional commit message analysis, intelligent staging, and message generation. Use when u…
buiducnhat/cobrew
156
13
gsap-sequencing Complex GSAP timelines including labels, callbacks, nested timelines, and position parameters. Use when orchestrating…
bbeierle12/skill-mcp-claude
156
14
exploiting-broken-link-hijacking Discovers and exploits broken link hijacking by spidering a site (Burp Suite Spider, Scrapy, curl scraping), extracti…
mukul975/anthropic-cybersecurity-skills
156
15
cw-brainstorming Creative writing skill for capturing story brainstorming. Use when the user is exploring narrative ideas, discussing …
haowjy/creative-writing-skills
156
16
quarto-alt-text Generate accessible alt text for data visualizations in Quarto documents. Use when the user wants to add, improve, or…
posit-dev/skills
156
17
xiaohongshu-media-collector Collect validated Xiaohongshu image assets from normalized XHS datasets into local manifests and downloaded files. Us…
postplusai/postplus-skills
156
18
xiaohongshu-content-benchmark Benchmark Xiaohongshu posts from validated public account surfaces first, then extract reusable title hooks, cover pa…
postplusai/postplus-skills
156
19
narrative-design Structure the body and close of a short-form video into a reusable Narrative Brief with explicit arc choice, beat seq…
postplusai/postplus-skills
156
20
xiaohongshu-article-packager Lay out an existing draft or script into a Xiaohongshu image-post or long-image package without rewriting the source.…
postplusai/postplus-skills
156
21
xiaohongshu-tools Local execution tools for Xiaohongshu/Rednote hosted collection workflows, including actor runs, dataset normalizatio…
postplusai/postplus-skills
156
22
xiaohongshu-notes Develop Xiaohongshu note ideas and drafts from rough thoughts, lived experience, or existing source material. Use thi…
postplusai/postplus-skills
156
23
gdcli Google Drive CLI for listing, searching, uploading, downloading, and sharing files and folders.
badlogic/pi-skills
156
24
sobriety-tools-guardian Performance optimization and continuous improvement for sobriety.tools recovery app. Use for load time optimization, …
curiositech/some_claude_skills
156
25
checkpoint-resume Rate-limit-resilient pipeline with checkpoint/resume for long multi-phase sessions. Saves progress to .claude/pipelin…
yonatangross/orchestkit
156
26
databricks-zerobus-ingest Build Zerobus Ingest clients for near real-time data ingestion into Databricks Delta tables via gRPC. Use when creati…
databricks/databricks-agent-skills
156
27
databricks-unstructured-pdf-generation Build RAG / unstructured-document evaluation datasets and demo documents (e.g. for Knowledge Assistant) on Databricks…
databricks/databricks-agent-skills
156
28
triton-lang Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/stor…
mohitmishra786/low-level-dev-skills
156
29
grdb Use when writing raw SQL with GRDB, complex joins across 4+ tables, window functions, ValueObservation for reactive q…
johnrogers/claude-swift-engineering
156
30
ccxt-php CCXT cryptocurrency exchange library for PHP developers. Covers both REST API (standard) and WebSocket API (real-time…
ccxt/ccxt
156
31
marketo Marketo integration. Manage Leads, Persons, Organizations, Activities, Notes, Files and more. Use when the user wants…
membranedev/application-skills
156
32
mail-blaze Mail Blaze integration. Manage data, records, and automate workflows. Use when the user wants to interact with Mail B…
membranedev/application-skills
156
33
sms-magic SMS Magic integration. Manage SMSes, Contacts, Conversations, Templates, Campaigns, Lists. Use when the user wants to…
membranedev/application-skills
156
34
temenos-t24-transact Temenos T24 Transact integration. Manage data, records, and automate workflows. Use when the user wants to interact w…
membranedev/application-skills
156
35
learn Optionally analyze collections of durable verdicts for recurring evidence after the critical path. Triggers: "learn f…
boshu2/agentops
156
36
risk-management Enterprise risk management expertise for ERM frameworks, risk assessment, business continuity, insurance strategy, th…
travisjneuman/.claude
156
37
1password 使用 1Password CLI (op) 管理密码和 API credentials。保存、查询、读取 API key/token,注入环境变量到脚本。当用户提到保…
iamzhihuix/happy-claude-skills
156
38
godot-genre-shooter-fps Expert blueprint for First-Person Shooters: fps_camera_look, fps_movement_logic, hitscan_weapon_query, weapon_bobbing…
thedivergentai/gd-agentic-skills
156
39
react-core General React fundamentals - components and JSX, props and state, the core hooks (useState/useEffect/useRef/useMemo/u…
bobmatnyc/claude-mpm-skills
156
40
code-quality Python code-quality anti-patterns and review checks: exception-hierarchy correctness, singleton identity comparison, …
bobmatnyc/claude-mpm-skills
156
41
skill-creator Create or update agent skills with concise SKILL.md instructions, bundled resources, agent metadata, validation, and …
dkyazzentwatwa/chatgpt-skills
156
42
triage-flaky-test Load when investigating a specific flaky test. Gets history, failure pattern, and category, then recommends fix, quar…
datadog-labs/agent-skills
156
43
docker-watch-mode-2025 Docker Compose Watch mode for hot reload during local development (2025 GA). PROACTIVELY activate for: (1) docker com…
josiahsiegel/claude-plugin-marketplace
156
44
ai-analyzer AI驱动的综合健康分析系统,整合多维度健康数据、识别异常模式、预测健康风险、提供个性化建议。支持智能问答和AI健康报告生…
sickn33/agentic-awesome-skills
156
45
fastapi-router-py Create FastAPI routers following established patterns with proper authentication, response models, and HTTP status co…
sickn33/agentic-awesome-skills
156
46
animation-basics Animation theory covering the 12 principles of animation and timing guidance. Use when designing motion, choosing eas…
videozero/skills
156
47
tuzi-cover-image 生成文章封面图片,?
tuziapi/tuzi-skills
156
48
flutter-development Cross-platform development with Flutter and Dart for iOS, Android, Web, Desktop, and embedded. Use when building Flut…
travisjneuman/.claude
156
49
syncfusion-maui-tab-view Implements Syncfusion .NET MAUI Tab View (SfTabView) controls for tab navigation interfaces and tabbed content layout…
syncfusion/maui-ui-components-skills
156
50
syncfusion-maui-combobox Implements Syncfusion .NET MAUI ComboBox (SfComboBox) control.
syncfusion/maui-ui-components-skills
156
Page 663 · 338,192 total Previous Next